# HG changeset patch
# Node ID b2633f2feb9e
# Parent  4eda25f19952
diff --git a/pidgin/meson.build b/pidgin/meson.build
--- a/pidgin/meson.build
+++ b/pidgin/meson.build
@@ -60,11 +60,11 @@ libpidgin_SOURCES = [
 	'pidginstylecontext.c',
 	'pidgintalkatu.c',
 	'prefs/pidginprefs.c',
-	'prefs/pidginawaypage.c',
+	'prefs/pidginawayprefs.c',
 	'prefs/pidginconversationprefs.c',
 	'prefs/pidgincredentialproviderrow.c',
-	'prefs/pidgincredentialspage.c',
-	'prefs/pidginnetworkpage.c',
+	'prefs/pidgincredentialprefs.c',
+	'prefs/pidginnetworkprefs.c',
 	'prefs/pidginproxyprefs.c',
 ]
 
@@ -132,11 +132,11 @@ libpidgin_headers = [
 
 libpidgin_prefs_headers = [
 	'prefs/pidginprefs.h',
-	'prefs/pidginawaypage.h',
+	'prefs/pidginawayprefs.h',
 	'prefs/pidginconversationprefs.h',
 	'prefs/pidgincredentialproviderrow.h',
-	'prefs/pidgincredentialspage.h',
-	'prefs/pidginnetworkpage.h',
+	'prefs/pidgincredentialprefs.h',
+	'prefs/pidginnetworkprefs.h',
 	'prefs/pidginproxyprefs.h',
 ]
 
diff --git a/pidgin/prefs/pidginawaypage.c b/pidgin/prefs/pidginawayprefs.c
rename from pidgin/prefs/pidginawaypage.c
rename to pidgin/prefs/pidginawayprefs.c
--- a/pidgin/prefs/pidginawaypage.c
+++ b/pidgin/prefs/pidginawayprefs.c
@@ -24,12 +24,12 @@
 
 #include <handy.h>
 
-#include "pidginawaypage.h"
+#include "pidginawayprefs.h"
 #include "gtksavedstatuses.h"
 #include "gtkutils.h"
 #include "pidginprefsinternal.h"
 
-struct _PidginAwayPage {
+struct _PidginAwayPrefs {
 	HdyPreferencesPage parent;
 
 	PidginPrefCombo idle_reporting;
@@ -42,7 +42,7 @@ struct _PidginAwayPage {
 	GtkWidget *startup_label;
 };
 
-G_DEFINE_TYPE(PidginAwayPage, pidgin_away_page, HDY_TYPE_PREFERENCES_PAGE)
+G_DEFINE_TYPE(PidginAwayPrefs, pidgin_away_prefs, HDY_TYPE_PREFERENCES_PAGE)
 
 /******************************************************************************
  * Helpers
@@ -65,7 +65,7 @@ set_startupstatus(PurpleSavedStatus *sta
  * GObject Implementation
  *****************************************************************************/
 static void
-pidgin_away_page_class_init(PidginAwayPageClass *klass)
+pidgin_away_prefs_class_init(PidginAwayPrefsClass *klass)
 {
 	GtkWidgetClass *widget_class = GTK_WIDGET_CLASS(klass);
 
@@ -74,69 +74,69 @@ pidgin_away_page_class_init(PidginAwayPa
 	    "/im/pidgin/Pidgin3/Prefs/away.ui"
 	);
 
-	gtk_widget_class_bind_template_child(
-			widget_class, PidginAwayPage, idle_reporting.combo);
-	gtk_widget_class_bind_template_child(
-			widget_class, PidginAwayPage, mins_before_away);
-	gtk_widget_class_bind_template_child(
-			widget_class, PidginAwayPage, away_when_idle);
-	gtk_widget_class_bind_template_child(
-			widget_class, PidginAwayPage, idle_hbox);
-	gtk_widget_class_bind_template_child(
-			widget_class, PidginAwayPage, auto_reply.combo);
-	gtk_widget_class_bind_template_child(
-			widget_class, PidginAwayPage, startup_current_status);
-	gtk_widget_class_bind_template_child(
-			widget_class, PidginAwayPage, startup_hbox);
-	gtk_widget_class_bind_template_child(
-			widget_class, PidginAwayPage, startup_label);
+	gtk_widget_class_bind_template_child(widget_class, PidginAwayPrefs,
+	                                     idle_reporting.combo);
+	gtk_widget_class_bind_template_child(widget_class, PidginAwayPrefs,
+	                                     mins_before_away);
+	gtk_widget_class_bind_template_child(widget_class, PidginAwayPrefs,
+	                                     away_when_idle);
+	gtk_widget_class_bind_template_child(widget_class, PidginAwayPrefs,
+	                                     idle_hbox);
+	gtk_widget_class_bind_template_child(widget_class, PidginAwayPrefs,
+	                                     auto_reply.combo);
+	gtk_widget_class_bind_template_child(widget_class, PidginAwayPrefs,
+	                                     startup_current_status);
+	gtk_widget_class_bind_template_child(widget_class, PidginAwayPrefs,
+	                                     startup_hbox);
+	gtk_widget_class_bind_template_child(widget_class, PidginAwayPrefs,
+	                                     startup_label);
 }
 
 static void
-pidgin_away_page_init(PidginAwayPage *page)
+pidgin_away_prefs_init(PidginAwayPrefs *prefs)
 {
 	GtkWidget *menu;
 
-	gtk_widget_init_template(GTK_WIDGET(page));
+	gtk_widget_init_template(GTK_WIDGET(prefs));
 
-	page->idle_reporting.type = PURPLE_PREF_STRING;
-	page->idle_reporting.key = "/purple/away/idle_reporting";
-	pidgin_prefs_bind_dropdown(&page->idle_reporting);
+	prefs->idle_reporting.type = PURPLE_PREF_STRING;
+	prefs->idle_reporting.key = "/purple/away/idle_reporting";
+	pidgin_prefs_bind_dropdown(&prefs->idle_reporting);
 
 	pidgin_prefs_bind_spin_button("/purple/away/mins_before_away",
-			page->mins_before_away);
+			prefs->mins_before_away);
 
 	pidgin_prefs_bind_checkbox("/purple/away/away_when_idle",
-			page->away_when_idle);
+			prefs->away_when_idle);
 
 	/* TODO: Show something useful if we don't have any saved statuses. */
 	menu = pidgin_status_menu(purple_savedstatus_get_idleaway(),
 	                          G_CALLBACK(set_idle_away));
 	gtk_widget_show_all(menu);
-	gtk_box_pack_start(GTK_BOX(page->idle_hbox), menu, FALSE, FALSE, 0);
+	gtk_box_pack_start(GTK_BOX(prefs->idle_hbox), menu, FALSE, FALSE, 0);
 
-	g_object_bind_property(page->away_when_idle, "active",
+	g_object_bind_property(prefs->away_when_idle, "active",
 			menu, "sensitive",
 			G_BINDING_SYNC_CREATE);
 
 	/* Away stuff */
-	page->auto_reply.type = PURPLE_PREF_STRING;
-	page->auto_reply.key = "/purple/away/auto_reply";
-	pidgin_prefs_bind_dropdown(&page->auto_reply);
+	prefs->auto_reply.type = PURPLE_PREF_STRING;
+	prefs->auto_reply.key = "/purple/away/auto_reply";
+	pidgin_prefs_bind_dropdown(&prefs->auto_reply);
 
 	/* Signon status stuff */
 	pidgin_prefs_bind_checkbox("/purple/savedstatus/startup_current_status",
-			page->startup_current_status);
+			prefs->startup_current_status);
 
 	/* TODO: Show something useful if we don't have any saved statuses. */
 	menu = pidgin_status_menu(purple_savedstatus_get_startup(),
 	                          G_CALLBACK(set_startupstatus));
 	gtk_widget_show_all(menu);
-	gtk_box_pack_start(GTK_BOX(page->startup_hbox), menu, FALSE, FALSE, 0);
-	gtk_label_set_mnemonic_widget(GTK_LABEL(page->startup_label), menu);
-	pidgin_set_accessible_label(menu, GTK_LABEL(page->startup_label));
-	g_object_bind_property(page->startup_current_status, "active",
-			page->startup_hbox, "sensitive",
+	gtk_box_pack_start(GTK_BOX(prefs->startup_hbox), menu, FALSE, FALSE, 0);
+	gtk_label_set_mnemonic_widget(GTK_LABEL(prefs->startup_label), menu);
+	pidgin_set_accessible_label(menu, GTK_LABEL(prefs->startup_label));
+	g_object_bind_property(prefs->startup_current_status, "active",
+			prefs->startup_hbox, "sensitive",
 			G_BINDING_SYNC_CREATE|G_BINDING_INVERT_BOOLEAN);
 }
 
@@ -144,6 +144,6 @@ pidgin_away_page_init(PidginAwayPage *pa
  * API
  *****************************************************************************/
 GtkWidget *
-pidgin_away_page_new(void) {
-	return GTK_WIDGET(g_object_new(PIDGIN_TYPE_AWAY_PAGE, NULL));
+pidgin_away_prefs_new(void) {
+	return GTK_WIDGET(g_object_new(PIDGIN_TYPE_AWAY_PREFS, NULL));
 }
diff --git a/pidgin/prefs/pidgincredentialspage.c b/pidgin/prefs/pidgincredentialprefs.c
rename from pidgin/prefs/pidgincredentialspage.c
rename to pidgin/prefs/pidgincredentialprefs.c
--- a/pidgin/prefs/pidgincredentialspage.c
+++ b/pidgin/prefs/pidgincredentialprefs.c
@@ -24,24 +24,24 @@
 
 #include <handy.h>
 
-#include "pidgincredentialspage.h"
+#include "pidgincredentialprefs.h"
 
 #include "pidgincredentialproviderrow.h"
 
-struct _PidginCredentialsPage {
+struct _PidginCredentialPrefs {
 	HdyPreferencesPage parent;
 
 	GtkWidget *credential_list;
 };
 
-G_DEFINE_TYPE(PidginCredentialsPage, pidgin_credentials_page,
+G_DEFINE_TYPE(PidginCredentialPrefs, pidgin_credential_prefs,
               HDY_TYPE_PREFERENCES_PAGE)
 
 /******************************************************************************
  * Helpers
  *****************************************************************************/
 static void
-pidgin_credentials_page_create_row(PurpleCredentialProvider *provider,
+pidgin_credential_prefs_create_row(PurpleCredentialProvider *provider,
                                    gpointer data)
 {
 	GtkListBox *box = GTK_LIST_BOX(data);
@@ -52,7 +52,7 @@ pidgin_credentials_page_create_row(Purpl
 }
 
 static gint
-pidgin_credentials_page_sort_rows(GtkListBoxRow *row1, GtkListBoxRow *row2,
+pidgin_credential_prefs_sort_rows(GtkListBoxRow *row1, GtkListBoxRow *row2,
                                   G_GNUC_UNUSED gpointer user_data)
 {
 	PidginCredentialProviderRow *pcprow = NULL;
@@ -85,9 +85,9 @@ pidgin_credentials_page_sort_rows(GtkLis
 }
 
 static void
-pidgin_credential_page_list_row_activated_cb(GtkListBox *box,
-                                             GtkListBoxRow *row,
-                                             G_GNUC_UNUSED gpointer data)
+pidgin_credential_prefs_list_row_activated_cb(GtkListBox *box,
+                                              GtkListBoxRow *row,
+                                              G_GNUC_UNUSED gpointer data)
 {
 	PurpleCredentialManager *manager = NULL;
 	PurpleCredentialProvider *provider = NULL;
@@ -103,7 +103,7 @@ pidgin_credential_page_list_row_activate
 		return;
 	}
 
-	purple_debug_warning("credentials-page", "failed to set the active "
+	purple_debug_warning("credential-prefs", "failed to set the active "
 			     "credential provider to '%s': %s",
 			     id, error ? error->message : "unknown error");
 
@@ -111,12 +111,12 @@ pidgin_credential_page_list_row_activate
 }
 
 static void
-pidgin_credentials_page_set_active_provider(PidginCredentialsPage *page,
+pidgin_credential_prefs_set_active_provider(PidginCredentialPrefs *prefs,
                                             const gchar *new_id)
 {
 	GList *rows = NULL;
 
-	rows = gtk_container_get_children(GTK_CONTAINER(page->credential_list));
+	rows = gtk_container_get_children(GTK_CONTAINER(prefs->credential_list));
 	for (; rows; rows = g_list_delete_link(rows, rows)) {
 		PidginCredentialProviderRow *row = NULL;
 		PurpleCredentialProvider *provider = NULL;
@@ -132,73 +132,73 @@ pidgin_credentials_page_set_active_provi
 }
 
 static void
-pidgin_credentials_page_active_provider_changed_cb(const gchar *name,
+pidgin_credential_prefs_active_provider_changed_cb(const gchar *name,
                                                    PurplePrefType type,
                                                    gconstpointer value,
                                                    gpointer data)
 {
-	PidginCredentialsPage *page = PIDGIN_CREDENTIALS_PAGE(data);
+	PidginCredentialPrefs *prefs = PIDGIN_CREDENTIAL_PREFS(data);
 
-	pidgin_credentials_page_set_active_provider(page, (const gchar *)value);
+	pidgin_credential_prefs_set_active_provider(prefs, (const gchar *)value);
 }
 
 /******************************************************************************
  * GObject Implementation
  *****************************************************************************/
 static void
-pidgin_credentials_page_finalize(GObject *obj) {
+pidgin_credential_prefs_finalize(GObject *obj) {
 	purple_prefs_disconnect_by_handle(obj);
 
-	G_OBJECT_CLASS(pidgin_credentials_page_parent_class)->finalize(obj);
+	G_OBJECT_CLASS(pidgin_credential_prefs_parent_class)->finalize(obj);
 }
 
 static void
-pidgin_credentials_page_init(PidginCredentialsPage *page) {
+pidgin_credential_prefs_init(PidginCredentialPrefs *prefs) {
 	PurpleCredentialManager *manager = NULL;
 	const gchar *active = NULL;
 
-	gtk_widget_init_template(GTK_WIDGET(page));
+	gtk_widget_init_template(GTK_WIDGET(prefs));
 
 	manager = purple_credential_manager_get_default();
 	purple_credential_manager_foreach(
 	    manager,
-	    pidgin_credentials_page_create_row,
-	    page->credential_list);
-	gtk_list_box_set_sort_func(GTK_LIST_BOX(page->credential_list),
-	                           pidgin_credentials_page_sort_rows, NULL, NULL);
+	    pidgin_credential_prefs_create_row,
+	    prefs->credential_list);
+	gtk_list_box_set_sort_func(GTK_LIST_BOX(prefs->credential_list),
+	                           pidgin_credential_prefs_sort_rows, NULL, NULL);
 
-	purple_prefs_connect_callback(page, "/purple/credentials/active-provider",
-	                              pidgin_credentials_page_active_provider_changed_cb,
-	                              page);
+	purple_prefs_connect_callback(prefs, "/purple/credentials/active-provider",
+	                              pidgin_credential_prefs_active_provider_changed_cb,
+	                              prefs);
 
 	active = purple_prefs_get_string("/purple/credentials/active-provider");
 	if(active != NULL) {
-		pidgin_credentials_page_set_active_provider(page, active);
+		pidgin_credential_prefs_set_active_provider(prefs, active);
 	}
 }
 
 static void
-pidgin_credentials_page_class_init(PidginCredentialsPageClass *klass) {
+pidgin_credential_prefs_class_init(PidginCredentialPrefsClass *klass) {
 	GObjectClass *obj_class = G_OBJECT_CLASS(klass);
 	GtkWidgetClass *widget_class = GTK_WIDGET_CLASS(klass);
 
-	obj_class->finalize = pidgin_credentials_page_finalize;
+	obj_class->finalize = pidgin_credential_prefs_finalize;
 
 	gtk_widget_class_set_template_from_resource(
 	    widget_class,
 	    "/im/pidgin/Pidgin3/Prefs/credentials.ui"
 	);
 
-	gtk_widget_class_bind_template_child(widget_class, PidginCredentialsPage,
+	gtk_widget_class_bind_template_child(widget_class, PidginCredentialPrefs,
 	                                     credential_list);
 	gtk_widget_class_bind_template_callback(widget_class,
-	                                        pidgin_credential_page_list_row_activated_cb);
+	                                        pidgin_credential_prefs_list_row_activated_cb);
 }
 
 /******************************************************************************
  * API
  *****************************************************************************/
 GtkWidget *
-pidgin_credentials_page_new(void) {
-	return GTK_WIDGET(g_object_new(PIDGIN_TYPE_CREDENTIALS_PAGE, NULL));
+pidgin_credential_prefs_new(void) {
+	return GTK_WIDGET(g_object_new(PIDGIN_TYPE_CREDENTIAL_PREFS, NULL));
 }
diff --git a/pidgin/prefs/pidginnetworkpage.c b/pidgin/prefs/pidginnetworkprefs.c
rename from pidgin/prefs/pidginnetworkpage.c
rename to pidgin/prefs/pidginnetworkprefs.c
--- a/pidgin/prefs/pidginnetworkpage.c
+++ b/pidgin/prefs/pidginnetworkprefs.c
@@ -27,10 +27,10 @@
 #include <handy.h>
 #include <nice.h>
 
-#include "pidginnetworkpage.h"
+#include "pidginnetworkprefs.h"
 #include "pidginprefsinternal.h"
 
-struct _PidginNetworkPage {
+struct _PidginNetworkPrefs {
 	HdyPreferencesPage parent;
 
 	GtkWidget *stun_server;
@@ -49,7 +49,8 @@ struct _PidginNetworkPage {
 	GtkWidget *turn_password;
 };
 
-G_DEFINE_TYPE(PidginNetworkPage, pidgin_network_page, HDY_TYPE_PREFERENCES_PAGE)
+G_DEFINE_TYPE(PidginNetworkPrefs, pidgin_network_prefs,
+              HDY_TYPE_PREFERENCES_PAGE)
 
 /******************************************************************************
  * Helpers
@@ -146,7 +147,7 @@ auto_ip_button_clicked_cb(GtkWidget *but
  * GObject Implementation
  *****************************************************************************/
 static void
-pidgin_network_page_class_init(PidginNetworkPageClass *klass)
+pidgin_network_prefs_class_init(PidginNetworkPrefsClass *klass)
 {
 	GtkWidgetClass *widget_class = GTK_WIDGET_CLASS(klass);
 
@@ -155,108 +156,107 @@ pidgin_network_page_class_init(PidginNet
 		"/im/pidgin/Pidgin3/Prefs/network.ui"
 	);
 
-	gtk_widget_class_bind_template_child(
-			widget_class, PidginNetworkPage, stun_server);
-	gtk_widget_class_bind_template_child(
-			widget_class, PidginNetworkPage, auto_ip);
-	gtk_widget_class_bind_template_child(
-			widget_class, PidginNetworkPage, public_ip);
-	gtk_widget_class_bind_template_child(
-			widget_class, PidginNetworkPage, public_ip_hbox);
-	gtk_widget_class_bind_template_child(
-			widget_class, PidginNetworkPage, map_ports);
-	gtk_widget_class_bind_template_child(
-			widget_class, PidginNetworkPage, ports_range_use);
-	gtk_widget_class_bind_template_child(
-			widget_class, PidginNetworkPage, ports_range_hbox);
-	gtk_widget_class_bind_template_child(
-			widget_class, PidginNetworkPage, ports_range_start);
-	gtk_widget_class_bind_template_child(
-			widget_class, PidginNetworkPage, ports_range_end);
-	gtk_widget_class_bind_template_child(
-			widget_class, PidginNetworkPage, turn_server);
-	gtk_widget_class_bind_template_child(
-			widget_class, PidginNetworkPage, turn_port_udp);
-	gtk_widget_class_bind_template_child(
-			widget_class, PidginNetworkPage, turn_port_tcp);
-	gtk_widget_class_bind_template_child(
-			widget_class, PidginNetworkPage, turn_username);
-	gtk_widget_class_bind_template_child(
-			widget_class, PidginNetworkPage, turn_password);
+	gtk_widget_class_bind_template_child(widget_class, PidginNetworkPrefs,
+	                                     stun_server);
+	gtk_widget_class_bind_template_child(widget_class, PidginNetworkPrefs,
+	                                     auto_ip);
+	gtk_widget_class_bind_template_child(widget_class, PidginNetworkPrefs,
+	                                     public_ip);
+	gtk_widget_class_bind_template_child(widget_class, PidginNetworkPrefs,
+	                                     public_ip_hbox);
+	gtk_widget_class_bind_template_child(widget_class, PidginNetworkPrefs,
+	                                     map_ports);
+	gtk_widget_class_bind_template_child(widget_class, PidginNetworkPrefs,
+	                                     ports_range_use);
+	gtk_widget_class_bind_template_child(widget_class, PidginNetworkPrefs,
+	                                     ports_range_hbox);
+	gtk_widget_class_bind_template_child(widget_class, PidginNetworkPrefs,
+	                                     ports_range_start);
+	gtk_widget_class_bind_template_child(widget_class, PidginNetworkPrefs,
+	                                     ports_range_end);
+	gtk_widget_class_bind_template_child(widget_class, PidginNetworkPrefs,
+	                                     turn_server);
+	gtk_widget_class_bind_template_child(widget_class, PidginNetworkPrefs,
+	                                     turn_port_udp);
+	gtk_widget_class_bind_template_child(widget_class, PidginNetworkPrefs,
+	                                     turn_port_tcp);
+	gtk_widget_class_bind_template_child(widget_class, PidginNetworkPrefs,
+	                                     turn_username);
+	gtk_widget_class_bind_template_child(widget_class, PidginNetworkPrefs,
+	                                     turn_password);
 	gtk_widget_class_bind_template_callback(widget_class,
-			network_stun_server_changed_cb);
-	gtk_widget_class_bind_template_callback(widget_class,
-	                 auto_ip_button_clicked_cb);
+	                                        network_stun_server_changed_cb);
 	gtk_widget_class_bind_template_callback(widget_class,
-			network_ip_changed);
+	                                        auto_ip_button_clicked_cb);
+	gtk_widget_class_bind_template_callback(widget_class, network_ip_changed);
 	gtk_widget_class_bind_template_callback(widget_class,
-			network_turn_server_changed_cb);
+	                                        network_turn_server_changed_cb);
 }
 
 static void
-pidgin_network_page_init(PidginNetworkPage *page)
+pidgin_network_prefs_init(PidginNetworkPrefs *prefs)
 {
 	GtkStyleContext *context;
 	GtkCssProvider *ip_css;
 
-	gtk_widget_init_template(GTK_WIDGET(page));
+	gtk_widget_init_template(GTK_WIDGET(prefs));
 
-	gtk_entry_set_text(GTK_ENTRY(page->stun_server),
+	gtk_entry_set_text(GTK_ENTRY(prefs->stun_server),
 			purple_prefs_get_string("/purple/network/stun_server"));
 
-	pidgin_prefs_bind_checkbox("/purple/network/auto_ip", page->auto_ip);
-	auto_ip_button_clicked_cb(page->auto_ip, NULL); /* Update label */
+	pidgin_prefs_bind_checkbox("/purple/network/auto_ip", prefs->auto_ip);
+	auto_ip_button_clicked_cb(prefs->auto_ip, NULL); /* Update label */
 
-	gtk_entry_set_text(GTK_ENTRY(page->public_ip),
+	gtk_entry_set_text(GTK_ENTRY(prefs->public_ip),
 			purple_network_get_public_ip());
 
 	ip_css = gtk_css_provider_new();
 	gtk_css_provider_load_from_resource(ip_css,
 	                                    "/im/pidgin/Pidgin3/Prefs/ip.css");
 
-	context = gtk_widget_get_style_context(page->public_ip);
+	context = gtk_widget_get_style_context(prefs->public_ip);
 	gtk_style_context_add_provider(context,
 	                               GTK_STYLE_PROVIDER(ip_css),
 	                               GTK_STYLE_PROVIDER_PRIORITY_APPLICATION);
 
-	g_object_bind_property(page->auto_ip, "active",
-			page->public_ip_hbox, "sensitive",
+	g_object_bind_property(prefs->auto_ip, "active",
+			prefs->public_ip_hbox, "sensitive",
 			G_BINDING_SYNC_CREATE|G_BINDING_INVERT_BOOLEAN);
 
 	pidgin_prefs_bind_checkbox("/purple/network/map_ports",
-			page->map_ports);
+			prefs->map_ports);
 
 	pidgin_prefs_bind_checkbox("/purple/network/ports_range_use",
-			page->ports_range_use);
-	g_object_bind_property(page->ports_range_use, "active",
-			page->ports_range_hbox, "sensitive",
+			prefs->ports_range_use);
+	g_object_bind_property(prefs->ports_range_use, "active",
+			prefs->ports_range_hbox, "sensitive",
 			G_BINDING_SYNC_CREATE);
 
 	pidgin_prefs_bind_spin_button("/purple/network/ports_range_start",
-			page->ports_range_start);
+			prefs->ports_range_start);
 	pidgin_prefs_bind_spin_button("/purple/network/ports_range_end",
-			page->ports_range_end);
+			prefs->ports_range_end);
 
 	/* TURN server */
-	gtk_entry_set_text(GTK_ENTRY(page->turn_server),
+	gtk_entry_set_text(GTK_ENTRY(prefs->turn_server),
 			purple_prefs_get_string("/purple/network/turn_server"));
 
 	pidgin_prefs_bind_spin_button("/purple/network/turn_port",
-			page->turn_port_udp);
+			prefs->turn_port_udp);
 
 	pidgin_prefs_bind_spin_button("/purple/network/turn_port_tcp",
-			page->turn_port_tcp);
+			prefs->turn_port_tcp);
 
 	pidgin_prefs_bind_entry("/purple/network/turn_username",
-			page->turn_username);
+			prefs->turn_username);
 	pidgin_prefs_bind_entry("/purple/network/turn_password",
-			page->turn_password);
+			prefs->turn_password);
 }
 
 /******************************************************************************
  * API
  *****************************************************************************/
 GtkWidget *
-pidgin_network_page_new(void) {
-	return GTK_WIDGET(g_object_new(PIDGIN_TYPE_NETWORK_PAGE, NULL));
+pidgin_network_prefs_new(void) {
+	return GTK_WIDGET(g_object_new(PIDGIN_TYPE_NETWORK_PREFS, NULL));
 }
diff --git a/pidgin/prefs/pidginproxyprefs.c b/pidgin/prefs/pidginproxyprefs.c
--- a/pidgin/prefs/pidginproxyprefs.c
+++ b/pidgin/prefs/pidginproxyprefs.c
@@ -56,32 +56,32 @@ static void
 proxy_changed_cb(const gchar *name, PurplePrefType type, gconstpointer value,
                  gpointer data)
 {
-	PidginProxyPrefs *page = data;
+	PidginProxyPrefs *prefs = data;
 	const char *proxy = value;
 
 	if (!purple_strequal(proxy, "none") && !purple_strequal(proxy, "envvar")) {
-		gtk_widget_show_all(page->options);
+		gtk_widget_show_all(prefs->options);
 	} else {
-		gtk_widget_hide(page->options);
+		gtk_widget_hide(prefs->options);
 	}
 }
 
 static void
 proxy_print_option(GtkWidget *entry, gpointer data)
 {
-	PidginProxyPrefs *page = data;
+	PidginProxyPrefs *prefs = data;
 
-	if (entry == page->host) {
+	if (entry == prefs->host) {
 		purple_prefs_set_string("/purple/proxy/host",
 				gtk_entry_get_text(GTK_ENTRY(entry)));
-	} else if (entry == page->port) {
+	} else if (entry == prefs->port) {
 		purple_prefs_set_int("/purple/proxy/port",
 				gtk_spin_button_get_value_as_int(
 					GTK_SPIN_BUTTON(entry)));
-	} else if (entry == page->username) {
+	} else if (entry == prefs->username) {
 		purple_prefs_set_string("/purple/proxy/username",
 				gtk_entry_get_text(GTK_ENTRY(entry)));
-	} else if (entry == page->password) {
+	} else if (entry == prefs->password) {
 		purple_prefs_set_string("/purple/proxy/password",
 				gtk_entry_get_text(GTK_ENTRY(entry)));
 	}
@@ -90,10 +90,10 @@ proxy_print_option(GtkWidget *entry, gpo
 static void
 proxy_button_clicked_cb(GtkWidget *button, gpointer data)
 {
-	PidginProxyPrefs *page = data;
+	PidginProxyPrefs *prefs = data;
 	GError *err = NULL;
 
-	if (g_spawn_command_line_async(page->gnome_program_path, &err)) {
+	if (g_spawn_command_line_async(prefs->gnome_program_path, &err)) {
 		return;
 	}
 
@@ -156,16 +156,16 @@ pidgin_proxy_prefs_class_init(PidginProx
 }
 
 static void
-pidgin_proxy_prefs_init(PidginProxyPrefs *page)
+pidgin_proxy_prefs_init(PidginProxyPrefs *prefs)
 {
 	PurpleProxyInfo *proxy_info;
 
-	gtk_widget_init_template(GTK_WIDGET(page));
+	gtk_widget_init_template(GTK_WIDGET(prefs));
 
 	if(purple_running_gnome()) {
 		gchar *path = NULL;
 
-		gtk_stack_set_visible_child_name(GTK_STACK(page->stack),
+		gtk_stack_set_visible_child_name(GTK_STACK(prefs->stack),
 				"gnome");
 
 		path = g_find_program_in_path("gnome-network-properties");
@@ -181,52 +181,52 @@ pidgin_proxy_prefs_init(PidginProxyPrefs
 			}
 		}
 
-		page->gnome_program_path = path;
-		gtk_widget_set_visible(page->gnome_not_found, path == NULL);
-		gtk_widget_set_visible(page->gnome_program, path != NULL);
+		prefs->gnome_program_path = path;
+		gtk_widget_set_visible(prefs->gnome_not_found, path == NULL);
+		gtk_widget_set_visible(prefs->gnome_program, path != NULL);
 	} else {
-		gtk_stack_set_visible_child_name(GTK_STACK(page->stack),
+		gtk_stack_set_visible_child_name(GTK_STACK(prefs->stack),
 				"nongnome");
 
 		/* This is a global option that affects SOCKS4 usage even with
 		 * account-specific proxy settings */
 		pidgin_prefs_bind_checkbox("/purple/proxy/socks4_remotedns",
-				page->socks4_remotedns);
+				prefs->socks4_remotedns);
 
-		page->type.type = PURPLE_PREF_STRING;
-		page->type.key = "/purple/proxy/type";
-		pidgin_prefs_bind_dropdown(&page->type);
+		prefs->type.type = PURPLE_PREF_STRING;
+		prefs->type.key = "/purple/proxy/type";
+		pidgin_prefs_bind_dropdown(&prefs->type);
 		proxy_info = purple_global_proxy_get_info();
 
-		purple_prefs_connect_callback(page, "/purple/proxy/type",
-				proxy_changed_cb, page);
+		purple_prefs_connect_callback(prefs, "/purple/proxy/type",
+				proxy_changed_cb, prefs);
 
 		if (proxy_info != NULL) {
 			if (purple_proxy_info_get_hostname(proxy_info)) {
-				gtk_entry_set_text(GTK_ENTRY(page->host),
+				gtk_entry_set_text(GTK_ENTRY(prefs->host),
 						purple_proxy_info_get_hostname(proxy_info));
 			}
 
 			if (purple_proxy_info_get_port(proxy_info) != 0) {
 				gtk_spin_button_set_value(
-						GTK_SPIN_BUTTON(page->port),
+						GTK_SPIN_BUTTON(prefs->port),
 						purple_proxy_info_get_port(proxy_info));
 			}
 
 			if (purple_proxy_info_get_username(proxy_info) != NULL) {
-				gtk_entry_set_text(GTK_ENTRY(page->username),
+				gtk_entry_set_text(GTK_ENTRY(prefs->username),
 						purple_proxy_info_get_username(proxy_info));
 			}
 
 			if (purple_proxy_info_get_password(proxy_info) != NULL) {
-				gtk_entry_set_text(GTK_ENTRY(page->password),
+				gtk_entry_set_text(GTK_ENTRY(prefs->password),
 						purple_proxy_info_get_password(proxy_info));
 			}
 		}
 
 		proxy_changed_cb("/purple/proxy/type", PURPLE_PREF_STRING,
 			purple_prefs_get_string("/purple/proxy/type"),
-			page);
+			prefs);
 	}
 }
 
diff --git a/pidgin/resources/Prefs/away.ui b/pidgin/resources/Prefs/away.ui
--- a/pidgin/resources/Prefs/away.ui
+++ b/pidgin/resources/Prefs/away.ui
@@ -75,7 +75,7 @@ along with this program; if not, see <ht
     <property name="step-increment">1</property>
     <property name="page-increment">10</property>
   </object>
-  <template class="PidginAwayPage" parent="HdyPreferencesPage">
+  <template class="PidginAwayPrefs" parent="HdyPreferencesPage">
     <property name="visible">True</property>
     <property name="can-focus">False</property>
     <child>
diff --git a/pidgin/resources/Prefs/credentials.ui b/pidgin/resources/Prefs/credentials.ui
--- a/pidgin/resources/Prefs/credentials.ui
+++ b/pidgin/resources/Prefs/credentials.ui
@@ -26,7 +26,7 @@ Foundation, Inc., 51 Franklin Street, Fi
   <!-- interface-name Pidgin -->
   <!-- interface-description Internet Messenger -->
   <!-- interface-copyright Pidgin Developers <devel@pidgin.im> -->
-  <template class="PidginCredentialsPage" parent="HdyPreferencesPage">
+  <template class="PidginCredentialPrefs" parent="HdyPreferencesPage">
     <property name="visible">True</property>
     <property name="can-focus">False</property>
     <property name="title" translatable="yes">Credentials</property>
@@ -41,7 +41,7 @@ Foundation, Inc., 51 Franklin Street, Fi
             <property name="visible">True</property>
             <property name="can-focus">False</property>
             <property name="selection-mode">none</property>
-            <signal name="row-activated" handler="pidgin_credential_page_list_row_activated_cb" after="yes" swapped="no"/>
+            <signal name="row-activated" handler="pidgin_credential_prefs_list_row_activated_cb" after="yes" swapped="no"/>
             <style>
               <class name="content"/>
             </style>
diff --git a/pidgin/resources/Prefs/network.ui b/pidgin/resources/Prefs/network.ui
--- a/pidgin/resources/Prefs/network.ui
+++ b/pidgin/resources/Prefs/network.ui
@@ -44,7 +44,7 @@ along with this program; if not, see <ht
     <property name="step-increment">1</property>
     <property name="page-increment">10</property>
   </object>
-  <template class="PidginNetworkPage" parent="HdyPreferencesPage">
+  <template class="PidginNetworkPrefs" parent="HdyPreferencesPage">
     <property name="visible">True</property>
     <property name="can-focus">False</property>
     <child>
diff --git a/pidgin/resources/Prefs/prefs.ui b/pidgin/resources/Prefs/prefs.ui
--- a/pidgin/resources/Prefs/prefs.ui
+++ b/pidgin/resources/Prefs/prefs.ui
@@ -94,7 +94,7 @@ Foundation, Inc., 51 Franklin Street, Fi
                   </packing>
                 </child>
                 <child>
-                  <object class="PidginNetworkPage">
+                  <object class="PidginNetworkPrefs">
                     <property name="visible">True</property>
                     <property name="can-focus">False</property>
                   </object>
@@ -116,7 +116,7 @@ Foundation, Inc., 51 Franklin Street, Fi
                   </packing>
                 </child>
                 <child>
-                  <object class="PidginAwayPage">
+                  <object class="PidginAwayPrefs">
                     <property name="visible">True</property>
                     <property name="can-focus">False</property>
                   </object>
@@ -127,7 +127,7 @@ Foundation, Inc., 51 Franklin Street, Fi
                   </packing>
                 </child>
                 <child>
-                  <object class="PidginCredentialsPage">
+                  <object class="PidginCredentialPrefs">
                     <property name="visible">True</property>
                     <property name="can-focus">False</property>
                   </object>

diff --git a/pidgin/prefs/pidginawaypage.h b/pidgin/prefs/pidginawayprefs.h
rename from pidgin/prefs/pidginawaypage.h
rename to pidgin/prefs/pidginawayprefs.h
--- a/pidgin/prefs/pidginawaypage.h
+++ b/pidgin/prefs/pidginawayprefs.h
@@ -24,8 +24,8 @@
 # error "only <pidgin.h> may be included directly"
 #endif
 
-#ifndef PIDGIN_AWAY_PAGE_H
-#define PIDGIN_AWAY_PAGE_H
+#ifndef PIDGIN_AWAY_PREFS_H
+#define PIDGIN_AWAY_PREFS_H
 
 #include <glib.h>
 
@@ -35,28 +35,28 @@
 G_BEGIN_DECLS
 
 /**
- * PidginAwayPage:
+ * PidginAwayPrefs:
  *
  * #PidginAwayPage is a widget for the preferences window to let users
  * choose and configure their away and idle settings.
  *
  * Since: 3.0.0
  */
-#define PIDGIN_TYPE_AWAY_PAGE (pidgin_away_page_get_type())
-G_DECLARE_FINAL_TYPE(PidginAwayPage, pidgin_away_page,
-                     PIDGIN, AWAY_PAGE, HdyPreferencesPage)
+#define PIDGIN_TYPE_AWAY_PREFS (pidgin_away_prefs_get_type())
+G_DECLARE_FINAL_TYPE(PidginAwayPrefs, pidgin_away_prefs,
+                     PIDGIN, AWAY_PREFS, HdyPreferencesPage)
 
 /**
- * pidgin_away_page_new:
+ * pidgin_away_prefs_new:
  *
  * Creates a new #PidginAwayPage instance.
  *
  * Returns: (transfer full): The new #PidginAwayPage instance.
  *
  * Since: 3.0.0
  */
-GtkWidget *pidgin_away_page_new(void);
+GtkWidget *pidgin_away_prefs_new(void);
 
 G_END_DECLS
 
-#endif /* PIDGIN_AWAY_PAGE_H */
+#endif /* PIDGIN_AWAY_PREFS_H */
@@ -35,28 +35,28 @@
  *
- * #PidginAwayPage is a widget for the preferences window to let users
+ * #PidginAwayPrefs is a widget for the preferences window to let users
  * choose and configure their away and idle settings.
  *
@@ -35,28 +35,28 @@
  *
- * Creates a new #PidginAwayPage instance.
+ * Creates a new #PidginAwayPrefs instance.
  *
@@ -35,28 +35,28 @@
  *
- * Returns: (transfer full): The new #PidginAwayPage instance.
+ * Returns: (transfer full): The new #PidginAwayPrefs instance.
  *
  * Since: 3.0.0
diff --git a/pidgin/prefs/pidgincredentialspage.h b/pidgin/prefs/pidgincredentialprefs.h
rename from pidgin/prefs/pidgincredentialspage.h
rename to pidgin/prefs/pidgincredentialprefs.h
--- a/pidgin/prefs/pidgincredentialspage.h
+++ b/pidgin/prefs/pidgincredentialprefs.h
@@ -24,8 +24,8 @@
 # error "only <pidgin.h> may be included directly"
 #endif
 
-#ifndef PIDGIN_CREDENTIALS_PAGE_H
-#define PIDGIN_CREDENTIALS_PAGE_H
+#ifndef PIDGIN_CREDENTIAL_PREFS_H
+#define PIDGIN_CREDENTIAL_PREFS_H
 
 #include <glib.h>
 
@@ -35,36 +35,36 @@
 G_BEGIN_DECLS
 
 /**
- * PIDGIN_TYPE_CREDENTIALS_PAGE:
+ * PIDGIN_TYPE_CREDENTIAL_PREFS:
  *
  * The standard _get_type macro for #PidginCredentialsPage.
  *
  * Since: 3.0.0
  */
-#define PIDGIN_TYPE_CREDENTIALS_PAGE (pidgin_credentials_page_get_type())
-G_DECLARE_FINAL_TYPE(PidginCredentialsPage, pidgin_credentials_page,
-                     PIDGIN, CREDENTIALS_PAGE, HdyPreferencesPage)
+#define PIDGIN_TYPE_CREDENTIAL_PREFS (pidgin_credential_prefs_get_type())
+G_DECLARE_FINAL_TYPE(PidginCredentialPrefs, pidgin_credential_prefs,
+                     PIDGIN, CREDENTIAL_PREFS, HdyPreferencesPage)
 
 /**
- * PidginCredentialsPage:
+ * PidginCredentialPrefs:
  *
  * #PidginCredentialsPage is a widget for the preferences window to let users
  * choose and configure their credential provider.
  *
  * Since: 3.0.0
  */
 
 /**
- * pidgin_credentials_page_new:
+ * pidgin_credential_prefs_new:
  *
  * Creates a new #PidginCredentialsPage instance.
  *
  * Returns: (transfer full): The new #PidginCredentialsPage instance.
  *
  * Since: 3.0.0
  */
-GtkWidget *pidgin_credentials_page_new(void);
+GtkWidget *pidgin_credential_prefs_new(void);
 
 G_END_DECLS
 
-#endif /* PIDGIN_CREDENTIALS_PAGE_H */
+#endif /* PIDGIN_CREDENTIAL_PREFS_H */
@@ -35,36 +35,36 @@
  *
- * The standard _get_type macro for #PidginCredentialsPage.
+ * The standard _get_type macro for #PidginCredentialPrefs.
  *
  * Since: 3.0.0
@@ -35,36 +35,36 @@
  *
- * #PidginCredentialsPage is a widget for the preferences window to let users
+ * #PidginCredentialPrefs is a widget for the preferences window to let users
  * choose and configure their credential provider.
  *
@@ -35,36 +35,36 @@
  *
- * Creates a new #PidginCredentialsPage instance.
+ * Creates a new #PidginCredentialPrefs instance.
  *
@@ -35,36 +35,36 @@
  *
- * Returns: (transfer full): The new #PidginCredentialsPage instance.
+ * Returns: (transfer full): The new #PidginCredentialPrefs instance.
  *
  * Since: 3.0.0
diff --git a/pidgin/prefs/pidginnetworkpage.h b/pidgin/prefs/pidginnetworkprefs.h
rename from pidgin/prefs/pidginnetworkpage.h
rename to pidgin/prefs/pidginnetworkprefs.h
--- a/pidgin/prefs/pidginnetworkpage.h
+++ b/pidgin/prefs/pidginnetworkprefs.h
@@ -24,8 +24,8 @@
 # error "only <pidgin.h> may be included directly"
 #endif
 
-#ifndef PIDGIN_NETWORK_PAGE_H
-#define PIDGIN_NETWORK_PAGE_H
+#ifndef PIDGIN_NETWORK_PREFS_H
+#define PIDGIN_NETWORK_PREFS_H
 
 #include <glib.h>
 
@@ -35,28 +35,28 @@
 G_BEGIN_DECLS
 
 /**
- * PidginNetworkPage:
+ * PidginNetworkPrefs:
  *
  * #PidginNetworkPage is a widget for the preferences window to let users
  * choose and configure their network settings.
  *
  * Since: 3.0.0
  */
-#define PIDGIN_TYPE_NETWORK_PAGE (pidgin_network_page_get_type())
-G_DECLARE_FINAL_TYPE(PidginNetworkPage, pidgin_network_page,
-                     PIDGIN, NETWORK_PAGE, HdyPreferencesPage)
+#define PIDGIN_TYPE_NETWORK_PREFS (pidgin_network_prefs_get_type())
+G_DECLARE_FINAL_TYPE(PidginNetworkPrefs, pidgin_network_prefs,
+                     PIDGIN, NETWORK_PREFS, HdyPreferencesPage)
 
 /**
- * pidgin_network_page_new:
+ * pidgin_network_prefs_new:
  *
  * Creates a new #PidginNetworkPage instance.
  *
  * Returns: (transfer full): The new #PidginNetworkPage instance.
  *
  * Since: 3.0.0
  */
-GtkWidget *pidgin_network_page_new(void);
+GtkWidget *pidgin_network_prefs_new(void);
 
 G_END_DECLS
 
-#endif /* PIDGIN_NETWORK_PAGE_H */
+#endif /* PIDGIN_NETWORK_PREFS_H */
@@ -35,28 +35,28 @@
  *
- * #PidginNetworkPage is a widget for the preferences window to let users
+ * #PidginNetworkPrefs is a widget for the preferences window to let users
  * choose and configure their network settings.
  *
@@ -35,28 +35,28 @@
  *
- * Creates a new #PidginNetworkPage instance.
+ * Creates a new #PidginNetworkPrefs instance.
  *
@@ -35,28 +35,28 @@
  *
- * Returns: (transfer full): The new #PidginNetworkPage instance.
+ * Returns: (transfer full): The new #PidginNetworkPrefs instance.
  *
  * Since: 3.0.0